# SwaggerClient::JobsApi

All URIs are relative to *https://service.fax-api.de/4.0/rest*

Method | HTTP request | Description
------------- | ------------- | -------------
[**get_jobs**](JobsApi.md#get_jobs) | **GET** /jobs | /jobs
[**post_job**](JobsApi.md#post_job) | **POST** /jobs | /jobs

# **get_jobs**
> Jobs get_jobs(opts)

/jobs

Description: Resource to obtain a list of fax jobs

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure API key authorization: ApiAuthKey
  config.api_key['X-Auth-Token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Auth-Token'] = 'Bearer'
end

api_instance = SwaggerClient::JobsApi.new
opts = { 
  object_limit: 100, # Integer | Query parameter to change de default limitation of objects in the result data array
  object_offset: 0, # Integer | Query parameter to change de default offset of objects in the result data array
  filter_same_account: false, # BOOLEAN | Query parameter to fetch jobs after the api account linked to the used token/key for authorization
  filter_title: 'filter_title_example', # String | Query parameter to fetch jobs after his title
  filter_status: 'filter_status_example', # String | Query parameter to fetch jobs after his status
  filter_date_from: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
  filter_date_to: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
  filter_date_until_from: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+01:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00)
  filter_date_until_to: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like '2022-01-01T10:00:00+02:00'. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00
  filter_cost_center: 'filter_cost_center_example', # String | Query parameter to fetch jobs after his cost center
  sort_field: 'sort_field_example', # String | Available sort options for the result data array.
  sort_order: 'asc' # String | Describes the order for used sort fields
}

begin
  #/jobs
  result = api_instance.get_jobs(opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling JobsApi->get_jobs: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **object_limit** | **Integer**| Query parameter to change de default limitation of objects in the result data array | [optional] [default to 100]
 **object_offset** | **Integer**| Query parameter to change de default offset of objects in the result data array | [optional] [default to 0]
 **filter_same_account** | **BOOLEAN**| Query parameter to fetch jobs after the api account linked to the used token/key for authorization | [optional] [default to false]
 **filter_title** | **String**| Query parameter to fetch jobs after his title | [optional] 
 **filter_status** | **String**| Query parameter to fetch jobs after his status | [optional] 
 **filter_date_from** | **DateTime**| Query parameter to fetch jobs with a later date in TimeToSend. Can be combined with filterDateTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional] 
 **filter_date_to** | **DateTime**| Query parameter to fetch jobs with a previous date in TimeToSend. Can be combined with filterDateFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional] 
 **filter_date_until_from** | **DateTime**| Query parameter to fetch jobs with a later date in TimeToSendUntil. Can be combined with filterDateUntilTo to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+01:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00) | [optional] 
 **filter_date_until_to** | **DateTime**| Query parameter to fetch jobs with a previous date in TimeToSendUntil. Can be combined with filterDateUIntilFrom to define a period of interest. The format must comply with ISO 8601 and must contain date and time, like &#x27;2022-01-01T10:00:00+02:00&#x27;. Please also consider urlencoding (2022-01-01T10%3A00%3A00%2B01%3A00 | [optional] 
 **filter_cost_center** | **String**| Query parameter to fetch jobs after his cost center | [optional] 
 **sort_field** | **String**| Available sort options for the result data array. | [optional] 
 **sort_order** | **String**| Describes the order for used sort fields | [optional] [default to asc]

### Return type

[**Jobs**](Jobs.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **post_job**
> InlineResponse201 post_job(body)

/jobs

Description: Resource to create a new fax job

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
  # Configure API key authorization: ApiAuthKey
  config.api_key['X-Auth-Token'] = 'YOUR API KEY'
  # Uncomment the following line to set a prefix for the API key, e.g. 'Bearer' (defaults to nil)
  #config.api_key_prefix['X-Auth-Token'] = 'Bearer'
end

api_instance = SwaggerClient::JobsApi.new
body = SwaggerClient::JobPost.new # JobPost | Describes the required request body to create a new fax job


begin
  #/jobs
  result = api_instance.post_job(body)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling JobsApi->post_job: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**JobPost**](JobPost.md)| Describes the required request body to create a new fax job | 

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

[ApiAuthKey](../README.md#ApiAuthKey)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



